==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/fr.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Tous les calendriers ne sont pas mis en cache",
"Everything seems to be completely cached" => "Tout semble être en cache",
"No calendars found." => "Aucun calendrier n'a été trouvé.",
"No events found." => "Aucun événement n'a été trouvé.",
"Wrong calendar" => "Mauvais calendrier",
"You do not have the permissions to edit this event." => "Vous n'avez pas les droits suffisants pour éditer cet événement.",
"The file contained either no events or all events are already saved in your calendar." => "Soit le fichier ne contient aucun événement soit tous les événements sont déjà enregistrés dans votre calendrier.",
"events has been saved in the new calendar" => "Les événements ont été enregistrés dans le nouveau calendrier",
"Import failed" => "Échec de l'import",
"events has been saved in your calendar" => "Les événements ont été enregistrés dans votre calendrier",
"New Timezone:" => "Nouveau fuseau horaire :",
"Timezone changed" => "Fuseau horaire modifié",
"Invalid request" => "Requête invalide",
"Calendar" => "Calendrier",
"Deletion failed" => "La suppression a échoué",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "utilisateur",
"group" => "groupe",
"Editable" => "Modifiable",
"Shareable" => "Partageable",
"Deletable" => "Effaçable",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, d MMM, yyyy",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"Sun." => "Dim.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mer.",
"Thu." => "Jeu",
"Fri." => "Ven.",
"Sat." => "Sam.",
"January" => "Janvier",
"February" => "Février",
"March" => "Mars",
"April" => "Avril",
"May" => "Mai",
"June" => "Juin",
"July" => "Juillet",
"August" => "Août",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Décembre",
"Jan." => "Jan.",
"Feb." => "Fév.",
"Mar." => "Mars",
"Apr." => "Avr.",
"May." => "Mai",
"Jun." => "Juin",
"Jul." => "Juil.",
"Aug." => "Août",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Nov.",
"Dec." => "Déc.",
"All day" => "Journée entière",
"New Calendar" => "Nouveau Calendrier",
"Missing or invalid fields" => "Champs manquants ou invalides",
"Title" => "Titre",
"From Date" => "De la date",
"From Time" => "De l'heure",
"To Date" => "A la date",
"To Time" => "A l'heure",
"The event ends before it starts" => "L'événement s'est terminé avant qu'il ne commence",
"There was a database fail" => "Il y a eu un échec dans la base de donnée",
"Birthday" => "Anniversaire",
"Business" => "Professionnel",
"Call" => "Appel",
"Clients" => "Clientèle",
"Deliverer" => "Livraison",
"Holidays" => "Vacances",
"Ideas" => "Idées",
"Journey" => "Déplacement",
"Jubilee" => "Jubilé",
"Meeting" => "Meeting",
"Other" => "Autre",
"Personal" => "Personnel",
"Projects" => "Projets",
"Questions" => "Questions",
"Work" => "Travail",
"by" => "par",
"unnamed" => "sans nom",
"You do not have the permissions to update this calendar." => "Vous n'avez pas les droits suffisants pour mettre à jour ce calendrier.",
"You do not have the permissions to delete this calendar." => "Vous n'avez pas les droits suffisants pour supprimer ce calendrier.",
"You do not have the permissions to add to this calendar." => "Vous n'avez pas les droits suffisants pour ajouter du contenu à ce calendrier.",
"You do not have the permissions to add events to this calendar." => "Vous n'avez pas les droits suffisants pour ajouter des événements à ce calendrier.",
"You do not have the permissions to delete this event." => "Vous n'avez pas les droits suffisants pour supprimer cet événement.",
"Busy" => "Occupé",
"Public" => "Publique",
"Private" => "Privé",
"Confidential" => "Confidentiel",
"Does not repeat" => "Pas de répétition",
"Daily" => "Quotidien",
"Weekly" => "Hebdomadaire",
"Every Weekday" => "Du lundi au vendredi",
"Bi-Weekly" => "Bi-hebdomadaire",
"Monthly" => "Mensuel",
"Yearly" => "Annuel",
"never" => "jamais",
"by occurrences" => "par occurrences",
"by date" => "par date",
"by monthday" => "par jour du mois",
"by weekday" => "par jour de la semaine",
"events week of month" => "événements du mois par semaine",
"first" => "premier",
"second" => "deuxième",
"third" => "troisième",
"fourth" => "quatrième",
"fifth" => "cinquième",
"last" => "dernier",
"by events date" => "par date d’événements",
"by yearday(s)" => "par jour(s) de l'année",
"by weeknumber(s)" => "par numéro de semaine(s)",
"by day and month" => "par jour et mois",
"Date" => "Date",
"Cal." => "Cal.",
"Week" => "Semaine",
"Month" => "Mois",
"List" => "Liste",
"Today" => "Aujourd'hui",
"Settings" => "Paramètres",
"Your calendars" => "Vos calendriers",
"CalDav Link" => "Lien CalDav",
"Share Calendar" => "Partager le calendrier",
"Download" => "Télécharger",
"Edit" => "Éditer",
"Delete" => "Supprimer",
"New calendar" => "Nouveau calendrier",
"Edit calendar" => "Éditer le calendrier",
"Displayname" => "Nom d'affichage",
"Active" => "Actif",
"Calendar color" => "Couleur du calendrier",
"Save" => "Sauvegarder",
"Submit" => "Soumettre",
"Cancel" => "Annuler",
"Edit an event" => "Éditer un événement",
"Export" => "Exporter",
"Eventinfo" => "Événement",
"Repeating" => "Occurences",
"Alarm" => "Alarmes",
"Attendees" => "Participants",
"Share" => "Partage",
"Title of the Event" => "Titre de l'événement",
"Category" => "Catégorie",
"Separate categories with commas" => "Séparer les catégories par des virgules",
"Edit categories" => "Modifier les catégories",
"Access Class" => "Classe d'accès",
"All Day Event" => "Journée entière",
"From" => "De",
"To" => "À",
"Advanced options" => "Options avancées",
"Location" => "Emplacement",
"Location of the Event" => "Emplacement de l'événement",
"Description" => "Description",
"Description of the Event" => "Description de l'événement",
"Repeat" => "Répétition",
"Advanced" => "Avancé",
"Select weekdays" => "Sélection des jours de la semaine",
"Select days" => "Sélection des jours",
"and the events day of year." => "et les événements de l'année par jour.",
"and the events day of month." => "et les événements du mois par jour.",
"Select months" => "Sélection des mois",
"Select weeks" => "Sélection des semaines",
"and the events week of year." => "et les événements de l'année par semaine.",
"Interval" => "Intervalle",
"End" => "Fin",
"occurrences" => "occurrences",
"create a new calendar" => "Créer un nouveau calendrier",
"Import a calendar file" => "Importer un fichier de calendriers",
"Please choose a calendar" => "Veuillez sélectionner un calendrier",
"Name of new calendar" => "Nom pour le nouveau calendrier",
"Take an available name!" => "Choisissez un nom disponible !",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Un calendrier de ce nom existe déjà. Si vous choisissez de continuer les calendriers seront fusionnés.",
"Remove all events from the selected calendar" => "Supprimer tous les événements du calendrier sélectionné",
"Import" => "Importer",
"Close Dialog" => "Fermer la fenêtre",
"Create a new event" => "Créer un nouvel événement",
"Share with:" => "Partager avec :",
"Shared with" => "Partagé avec",
"Unshare" => "Ne plus partager",
"Nobody" => "Personne",
"Shared via calendar" => "Partagé via le calendrier",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTE : Les actions effectuées sur les événements partagés via calendrier affecteront l'ensemble du partage de calendriers.",
"View an event" => "Voir un événement",
"No categories selected" => "Aucune catégorie sélectionnée",
"of" => "de",
"at" => "à",
"General" => "Généraux",
"Timezone" => "Fuseau horaire",
"Update timezone automatically" => "Mise à jour automatique du fuseau horaire",
"Time format" => "Format de l'heure",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Les semaines commencent le",
"Cache" => "Cache",
"Clear cache for repeating events" => "Nettoyer le cache des événements répétitifs",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Adresses de synchronisation des calendriers CalDAV",
"more info" => "plus d'infos",
"Primary address (Kontact et al)" => "Adresses principales (Kontact et assimilés)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "lien(s) iCalendar en lecture seule"
);

==> owncloud-7.0.4.tgz: owncloud/apps/calendar/l10n/fr.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Certains calendriers ne sont pas mis en cache",
"Everything seems to be completely cached" => "Tout semble être en cache",
"No calendars found." => "Aucun calendrier n'a été trouvé.",
"No events found." => "Aucun événement n'a été trouvé.",
"Wrong calendar" => "Mauvais calendrier",
"You do not have the permissions to edit this event." => "Vous n'avez pas les droits suffisants pour modifier cet événement.",
"The file contained either no events or all events are already saved in your calendar." => "Soit le fichier ne contient aucun événement soit tous les événements sont déjà enregistrés dans votre calendrier.",
"events have been saved in the new calendar" => "Les événements ont été enregistrés dans le nouveau calendrier",
"Import failed" => "Échec de l'importation",
"events have been saved in your calendar" => "Les événements ont été enregistrés dans votre calendrier",
"New Timezone:" => "Nouveau fuseau horaire :",
"Timezone changed" => "Fuseau horaire modifié",
"Invalid request" => "Requête invalide",
"Calendar" => "Calendrier",
"Deletion failed" => "La suppression a échoué",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "groupe",
"can edit" => "modification autorisée",
"can share" => "partage autorisé",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, d MMM, yyyy",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"Sun." => "Dim.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mer.",
"Thu." => "Jeu.",
"Fri." => "Ven.",
"Sat." => "Sam.",
"January" => "Janvier",
"February" => "Février",
"March" => "Mars",
"April" => "Avril",
"May" => "Mai",
"June" => "Juin",
"July" => "Juillet",
"August" => "Août",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Décembre",
"Jan." => "Jan.",
"Feb." => "Fév.",
"Mar." => "Mars",
"Apr." => "Avr.",
"May." => "Mai",
"Jun." => "Juin",
"Jul." => "Juil.",
"Aug." => "Août",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Nov.",
"Dec." => "Déc.",
"All day" => "Journée entière",
"New Calendar" => "Nouveau calendrier",
"Missing or invalid fields" => "Champs manquants ou invalides",
"Title" => "Titre",
"From Date" => "De la date",
"From Time" => "De l'heure",
"To Date" => "À la date",
"To Time" => "À l'heure",
"The event ends before it starts" => "L'événement se termine avant qu'il ne commence",
"There was a database fail" => "Il y a eu un échec dans la base de données",
"Interval is not valid. It must be a positive integer!" => "L’intervalle spécifié n’est pas valide, il doit s’agir d’un nombre entier positif !",
"Birthday" => "Anniversaire",
"Business" => "Professionnel",
"Call" => "Appel",
"Clients" => "Clientèle",
"Deliverer" => "Livraison",
"Holidays" => "Vacances",
"Ideas" => "Idées",
"Journey" => "Déplacement",
"Jubilee" => "Jubilé",
"Meeting" => "Réunion",
"Other" => "Autre",
"Personal" => "Personnel",
"Projects" => "Projets",
"Questions" => "Questions",
"Work" => "Travail",
"by" => "par",
"unnamed" => "sans nom",
"You do not have the permissions to update this calendar." => "Vous n'avez pas les droits suffisants pour mettre à jour ce calendrier.",
"You do not have the permissions to delete this calendar." => "Vous n'avez pas les droits suffisants pour supprimer ce calendrier.",
"You do not have the permissions to add to this calendar." => "Vous n'avez pas les droits suffisants pour ajouter du contenu à ce calendrier.",
"You do not have the permissions to add events to this calendar." => "Vous n'avez pas les droits suffisants pour ajouter des événements à ce calendrier.",
"You cannot add non-public events to a shared calendar." => "Vous ne pouvez pas ajouter des événements privés à un calendrier partagé.",
"You do not have the permissions to delete this event." => "Vous n'avez pas les droits suffisants pour supprimer cet événement.",
"Busy" => "Occupé",
"Show full event" => "Afficher l'événement complet",
"Show only busy" => "Afficher seulement les événements occupés",
"Hide event" => "Masquer l'événement",
"Does not repeat" => "Pas de répétition",
"Daily" => "Quotidien",
"Weekly" => "Hebdomadaire",
"Every Weekday" => "Du lundi au vendredi",
"Bi-Weekly" => "Bi-hebdomadaire",
"Monthly" => "Mensuel",
"Yearly" => "Annuel",
"never" => "jamais",
"by occurrences" => "par occurrences",
"by date" => "par date",
"by monthday" => "par jour du mois",
"by weekday" => "par jour de la semaine",
"events week of month" => "événements du mois par semaine",
"first" => "premier",
"second" => "deuxième",
"third" => "troisième",
"fourth" => "quatrième",
"fifth" => "cinquième",
"last" => "dernier",
"by events date" => "par date d’événement",
"by yearday(s)" => "par jour(s) de l'année",
"by weeknumber(s)" => "par numéro(s) de semaine(s)",
"by day and month" => "par jour et mois",
"Contact birthdays" => "Anniversaires des contacts",
"Date" => "Date",
"Cal." => "Cal.",
"Day" => "Jour",
"Week" => "Semaine",
"Month" => "Mois",
"Today" => "Aujourd'hui",
"CalDav Link" => "Lien CalDav",
"Timezone" => "Fuseau horaire",
"Update timezone automatically" => "Mise à jour automatique du fuseau horaire",
"Time format" => "Format de l'heure",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Les semaines commencent le",
"Cache" => "Cache",
"Clear cache for repeating events" => "Nettoyer le cache des événements répétitifs",
"Primary CalDAV address" => "Adresse CalDAV principale",
"iOS/OS X CalDAV address" => "Adresse CalDAV pour iOS/OS X",
"Share Calendar" => "Partager le calendrier",
"Download" => "Télécharger",
"Edit" => "Éditer",
"Delete" => "Supprimer",
"New calendar" => "Nouveau calendrier",
"Edit calendar" => "Éditer le calendrier",
"Edit event" => "Modifier l'événement",
"Save event" => "Enregistrer l'événement",
"Delete event" => "Supprimer l'événement",
"Eventinfo" => "Événement",
"Repeating" => "Occurrences",
"Alarm" => "Alarme",
"Attendees" => "Participants",
"Share" => "Partage",
"Title of the Event" => "Titre de l'événement",
"from" => "du",
"to" => "au",
"All Day Event" => "Journée entière",
"Advanced options" => "Options avancées",
"Location" => "Emplacement",
"Categories (separate by comma)" => "Catégories (séparées par une virgule)",
"Edit categories" => "Modifier les catégories",
"Description" => "Description",
"Export event" => "Exporter l'événement",
"Repeat" => "Répétition",
"Advanced" => "Avancé",
"Select weekdays" => "Sélection des jours de la semaine",
"Select days" => "Sélection des jours",
"and the events day of year." => "et les événements de l'année par jour.",
"and the events day of month." => "et les événements du mois par jour.",
"Select months" => "Sélection des mois",
"Select weeks" => "Sélection des semaines",
"and the events week of year." => "et les événements de l'année par semaine.",
"Interval" => "Intervalle",
"End" => "Fin",
"occurrences" => "occurrences",
"Visibility to people shared with" => "Visibilité pour les personnes ayant accès au partage",
"create a new calendar" => "Créer un nouveau calendrier",
"Import a calendar file" => "Importer un fichier de calendrier",
"Please choose a calendar" => "Veuillez sélectionner un calendrier",
"Name of new calendar" => "Nom du nouveau calendrier",
"Take an available name!" => "Choisissez un nom disponible !",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Un calendrier de ce nom existe déjà. Si vous choisissez de continuer les calendriers seront fusionnés.",
"Remove all events from the selected calendar" => "Supprimer tous les événements du calendrier sélectionné",
"Import" => "Importer",
"Close Dialog" => "Fermer la fenêtre",
"Create a new event" => "Créer un nouvel événement",
"Create event" => "Créer un événement",
"Share with user or group" => "Partager avec un utilisateur ou un groupe",
"Unshare" => "Ne plus partager",
"Not shared with anyone" => "N'est partagé avec personne",
"Send Email" => "Envoyer un courriel",
"Shared via calendar" => "Partagé via le calendrier",
"Not shared with anyone via calendar" => "N'est partagé avec personne via le calendrier",
"View an event" => "Voir un événement",
"Category" => "Catégorie",
"No categories selected" => "Aucune catégorie sélectionnée",
"%s of %s" => "%s de %s",
"Access Class" => "Classe d'accès",
"From" => "De",
"at" => "à",
"To" => "À"
);
